@@ -37,7 +37,7 @@ class GeoObjReader(BaseReader, ABC):
             trimmed = " ".join(trimmed.split())
             # check if current line is a classic vertex
             if trimmed.startswith("v "):
-                coordinates = [float(a) for a in trimmed[2:].split(" ")]
+                coordinates = list([float(a) for a in trimmed[2:].split(" ")])
                 res.vertices.append(coordinates)
             # check if current line is a face defintion
             elif trimmed.startswith("f "):
@@ -55,7 +55,7 @@ class GeoObjReader(BaseReader, ABC):
                 current_object.faces.append(face)
                 filled_group = True
             # check if current line is a group definition
-            elif trimmed.startswith("g "):
+            elif trimmed.startswith("g ") or trimmed.startswith("o "):
                 name = trimmed[2:]
                 # if it is the first group definition and if we have not found any other definition
                 # just set the name of the current group; otherwise it is a new group
@@ -73,17 +73,29 @@ class GeoObjReader(BaseReader, ABC):
             elif trimmed.startswith("crs "):
                 res.crs = trimmed[4:]
             # check if the current line defines the origin
-            elif trimmed.startswith("o "):
-                res.origin = [float(a) for a in trimmed[2:].split(" ")]
+            elif trimmed.startswith("or "):
+                res.origin = [float(a) for a in trimmed[3:].split(" ")]
             # check if the current line defines a file scale
             elif trimmed.startswith("sc "):
-                res.scaling = [float(a) for a in trimmed[3:].split(" ")]
+                scale = [float(a) for a in trimmed[3:].split(" ")]
+                if not found_group:
+                    res.scaling = scale
+                else:
+                    current_object.scaling = scale
             # check if the current line defines a file translation
             elif trimmed.startswith("t "):
-                res.translation = [float(a) for a in trimmed[2:].split(" ")]
+                translation = [float(a) for a in trimmed[2:].split(" ")]
+                if not found_group:
+                    res.translation = translation
+                else:
+                    current_object.translation = translation
             # check if the current line defines a file rotation
             elif trimmed.startswith("r "):
-                res.rotation = [float(a) for a in trimmed[2:].split(" ")]
+                rotation = [float(a) for a in trimmed[2:].split(" ")]
+                if not found_group:
+                    res.rotation = rotation
+                else:
+                    current_object.rotation = rotation
             elif trimmed.startswith("e "):
                 extent = [float(a) for a in trimmed[2:].split(" ")]
                 res.min_extent = extent[:3]
