@@ -25,9 +25,20 @@ class GeoPlyWriter(BaseWriter, ABC):
         :param write_binary: flag if file is a binary file
         :return:
         """
+        if len(data.objects) != 1:
+            raise Exception("GeoPLY can represent only one object. Minimize the data.")
+
         num_vertices = len(data.vertices)
         faces = []
         for obj in data.objects:
+            if (
+                obj.contains_scaling()
+                or obj.contains_rotation()
+                or obj.contains_translation()
+            ):
+                raise Exception(
+                    "GeoPLY does not support local object transformation information."
+                )
             for face in obj.faces:
                 faces.append(face)
         num_faces = len(faces)
